<?php
/*
* az általános függvények
*/

function test_input($data) {
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    return $data;
  }



/*
*Behúzzuk a headbe a parent theme style-t, majd behúzzuk a child theme style-t
*/
function my_theme_enqueue_styles() {

    $parent_style = 'twentynineteen-style'; // This is 'twentynineteen-style' for the Twenty Nineteen theme.

    wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css' );
    wp_enqueue_style( 'child-style',
        get_stylesheet_directory_uri() . '/style.css',
        array( $parent_style ),
        wp_get_theme()->get('Version')
    );
}
add_action( 'wp_enqueue_scripts', 'my_theme_enqueue_styles' );

/*
*Behúzzuk a jquery-t és az  ui-t
*/
function add_jquery_ui() {
    wp_enqueue_script( 'jquery-ui-core' );
    wp_enqueue_script( 'jquery-ui-widget' );
    wp_enqueue_script('jquery-ui-datepicker');
    wp_enqueue_script( 'jquery-ui-mouse' );
    wp_enqueue_script( 'jquery-ui-accordion' );
    wp_enqueue_script( 'jquery-ui-autocomplete' );
    wp_enqueue_script( 'jquery-ui-slider' );
    wp_enqueue_script( 'jquery-ui-tabs' );
    wp_enqueue_script( 'jquery-ui-sortable' );
    wp_enqueue_script( 'jquery-ui-draggable' );
    wp_enqueue_script( 'jquery-ui-droppable' );
    wp_enqueue_script( 'jquery-ui-datepicker' );
    wp_enqueue_script( 'jquery-ui-resize' );
    wp_enqueue_script( 'jquery-ui-dialog' );
    wp_enqueue_script( 'jquery-ui-button' );
}
add_action( 'wp_enqueue_scripts', 'add_jquery_ui' );

/*
* Behúzzuk a bootstrap-et, a saját script-et, és localizáljuk a saját scriptet, ez ahhoz kell, hogy a js használni tudjon változókat
*/
function my_scripts() {
    wp_enqueue_style('bootstrap4', 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/css/bootstrap.min.css');
    wp_enqueue_script( 'boot1','https://code.jquery.com/jquery-3.3.1.min.js', array( 'jquery' ),'',true );
    wp_enqueue_script( 'boot2','https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js', array( 'jquery' ),'',true );
    wp_enqueue_script( 'boot3','https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/js/bootstrap.min.js', array( 'jquery' ),'',true );
    wp_enqueue_script( 'classm8', get_stylesheet_directory_uri() . '/classm8_theme.js', array ( 'jquery', 'boot1', 'boot2', 'boot3'  ), 1.1, true);
    wp_localize_script( 'classm8', 'classm8_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    
    wp_enqueue_editor();
}
add_action( 'wp_enqueue_scripts', 'my_scripts' );


/*
* Behúzzuk a font-awsome css-t
*/

function enqueue_load_fa() {
  wp_enqueue_style( 'load-fa', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.11.2/css/all.css' );
}

add_action( 'wp_enqueue_scripts', 'enqueue_load_fa');


/*
*Behúzzuk a config file-t
*/
require_once('classm8_config.php');

/*
*Beállítjuk a favicon-t
*/
function classm8_favicon_link() {
    echo '<link rel="shortcut icon" type="image/x-icon" href="'.get_stylesheet_directory_uri().'/favicon/favicon.ico" />' . "\n"
        .'<link rel="apple-touch-icon" sizes="57x57" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-57x57.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="60x60" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-60x60.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="72x72" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-72x72.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="76x76" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-76x76.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="114x114" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-114x114.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="120x120" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-120x120.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="144x144" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-144x144.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="152x152" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-152x152.png">' . "\n"
	.'<link rel="apple-touch-icon" sizes="180x180" href="'.get_stylesheet_directory_uri().'/favicon/apple-icon-180x180.png">' . "\n"
	.'<link rel="icon" type="image/png" sizes="192x192"  href="'.get_stylesheet_directory_uri().'/favicon/android-icon-192x192.png">' . "\n"
	.'<link rel="icon" type="image/png" sizes="32x32" href="'.get_stylesheet_directory_uri().'/favicon/favicon-32x32.png">' . "\n"
	.'<link rel="icon" type="image/png" sizes="96x96" href="'.get_stylesheet_directory_uri().'/favicon/favicon-96x96.png">' . "\n"
	.'<link rel="icon" type="image/png" sizes="16x16" href="'.get_stylesheet_directory_uri().'/favicon/favicon-16x16.png">' . "\n"
	.'<link rel="manifest" href="'.get_stylesheet_directory_uri().'/favicon/manifest.json">' . "\n"
	.'<meta name="msapplication-TileColor" content="#ffffff">' . "\n"
	.'<meta name="msapplication-TileImage" content="'.get_stylesheet_directory_uri().'/favicon/ms-icon-144x144.png">' . "\n"
	.'<meta name="theme-color" content="#ffffff">' . "\n";

}
add_action( 'wp_head', 'classm8_favicon_link' );


/*
*A következő dolgokat csinálja, ha aktiváljuk a classm8 theme-t
*/
function classm8_theme_activation () {
    //ha nem classm8 az eleje a subdomainnek, akkor ne lehessen aktiválni, és adjon hibaüzenetet
    if(substr($_SERVER['HTTP_HOST'],0,strlen(CLASSM8_BRAND)) !== CLASSM8_BRAND &&
       substr($_SERVER['HTTP_HOST'],0,strlen('www.'.CLASSM8_BRAND)) !== 'www.'.CLASSM8_BRAND){
		function echo_error_of_classm8_subdomain() {
		    echo '<div class="error"><p><strong>Error</strong>: unacceptable subdomain, please change to classm8 subdomain before activate it</p></div>';
		}
		add_action('admin_notices', 'echo_error_of_classm8_subdomain');
		switch_theme('twentynineteen');
		
	}

    //létrehozzuk a teacher, és az admin role-t
    add_role('classm8_teacher','classm8_teacher');
    add_role('classm8_admin','classm8_admin');

}
add_action('after_switch_theme', 'classm8_theme_activation');

/*
*A következő dolgokat csinálja ha deaktiváljuk a classm8 themet
*/
function classm8_theme_deactivation () {
    //töröljük a teacher role-t
    remove_role('classm8_teacher');
}
add_action('switch_theme', 'classm8_theme_deactivation');

/*
*A következő elrjeti az admin bart
*/
add_action( 'init', 'disable_admin_bar', 1 );
function disable_admin_bar() {
    add_filter( 'show_admin_bar', '__return_false' );
}

/*
*A következő visszairányít a home page-re, ha hibás a login jelszó
*/

add_action( 'wp_login_failed', 'my_front_end_login_fail' ); 
function my_front_end_login_fail( $username ) {
     $referrer = $_SERVER['HTTP_REFERER'];
     if ( !empty($referrer) && !strstr($referrer,'wp-login') && !strstr($referrer,'wp-admin') ) {
          //wp_redirect( $referrer . '?login=failed' ); 
	  wp_redirect( home_url() );
          exit;
     }
}

/*
* A következő létrehozza a custom_post_type-ot, 
*/

function create_posttype() {
 
    register_post_type( 'classm8_g_desc',
    // CPT Options
        array(
            'labels' => array(
                'name' => __( 'classm8_g_desc' ),
                'singular_name' => __( 'classm8_g_desc' )
            ),
        )
    );
}
// Hooking up our function to theme setup
add_action( 'init', 'create_posttype' );


/*
* az ajax válaszok
*/

add_action("wp_ajax_save_server", function(){
    $user = wp_get_current_user();
    if(in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
	$server_name = test_input($_POST['server_name']);
	if($server_name == ''){
	    delete_option('classm8_server');
	}
	elseif(!get_option('classm8_server')){
	    add_option('classm8_server' , $server_name);
	}
	else{
	    update_option('classm8_server' , $server_name);
	}
	echo "success";
	die;
	}
    else{
        echo "No authentication";
        die;
    }
});
add_action("wp_ajax_nopriv_save_server", function(){echo 'No access'; die;} );

add_action("wp_ajax_get_server_name", function(){
    $user = wp_get_current_user();
    if(in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
	echo get_option('classm8_server');
	die;
    }
    else{
        echo "No authentication";
        die;
    }
});
add_action("wp_ajax_nopriv_get_server_name", function(){echo 'No access'; die;} );

add_action("wp_ajax_save_new_user", function(){
    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
        echo "No authentication";
        die;
    }
    
    $new_user_email = test_input($_POST['new_user_email']);
    $password = test_input($_POST['password']);
    $new_user_type = $_POST['new_user_type'] != 'admin' ? 'classm8_teacher' : 'classm8_admin'  ;
    
    $userdata = array(
	'user_login'    =>  $new_user_email,
	'user_email'    =>  $new_user_email,
	'user_pass'     =>  $password,
	'role'		=>  $new_user_type
	);

    $new_user = wp_insert_user( $userdata );
    
    if(is_int($new_user)){
	echo "success";
	die;
    }
    else{
	echo  $new_user -> get_error_message();
	die;
    }

});
add_action("wp_ajax_nopriv_save_new_user", function(){echo 'No access'; die;} );


add_action("wp_ajax_get_classm8_users", function(){
    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
        echo "No authentication";
        die;
    }

    $classm8_users = get_users( [ 'role__in' => [ 'classm8_teacher', 'classm8_admin' ] ]);
    
    $classm8_users_list = [];

    foreach($classm8_users as $user ){
	array_push($classm8_users_list , array(	"user_email" => $user -> user_email , 
						"roles" => in_array('classm8_admin' ,  $user -> roles ) ? 'classm8_admin' : 'classm8_teacher'
					    )
	    );
    }
        
    echo json_encode($classm8_users_list);
    die;

});
add_action("wp_ajax_nopriv_get_classm8_users", function(){echo 'No access'; die;} );


add_action("wp_ajax_delete_classm8_user", function(){
    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
        echo "No authentication";
        die;
    }

    $user_email = test_input($_POST['user_email']);

    $user = get_user_by('email', $user_email);

    if(wp_delete_user($user->ID)){
	echo "success";
	die;
    }
    else{
	echo "error in delete";
	die;
    }
});
add_action("wp_ajax_nopriv_delete_classm8_user", function(){echo 'No access'; die;} );


add_action("wp_ajax_get_classm8_game_id", function(){

    function isJson($string) {
        json_decode($string);
	return (json_last_error() == JSON_ERROR_NONE);
    }

	
    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin', 'classm8_teacher'))){
        echo "No authentication".$user -> roles[0];
        die;
    }

    $server = get_option('classm8_server');
    
    if(!$server){
	echo "Add server options!";
	die;
    }
    
    $game_id = file_get_contents($server.'/api/game_start?id='.$_POST['game_id']);
    
    if(!isJson($game_id)){
	echo "server error";
	die;
    }

    $game_id = json_decode($game_id, true);

    echo 	'<h3>'.$game_id["id"].'</h3>'
		.'<a href="'.$server.$game_id["id"].'" class="btn btn-info" role="button" target="_blank" style="margin: 3em;">START</a>';
		die;
});
add_action("wp_ajax_nopriv_get_classm8_game_id", function(){echo 'No access'; die;} );


add_action("wp_ajax_get_classm8_game_description", function(){

    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin', 'classm8_teacher'))){
        echo "No authentication".$user -> roles[0];
        die;
    }

    $server = get_option('classm8_server');

    if(!$server){
	echo "Add server options!";
	die;
    }

    $game_id =  (is_numeric($_POST['game_id']) ? (int)$_POST['game_id'] : 0);

    if(!is_int($game_id)){
	echo "game id error";
	die;
    }

    $post_title = 'cl_game_desc_'.md5($server).'_'.$game_id;

    $post = get_page_by_title($post_title, OBJECT, 'classm8_g_desc');

    echo apply_filters( 'the_content', $post->post_content );
    die;

});
add_action("wp_ajax_nopriv_get_classm8_game_description", function(){echo 'No access'; die;} );


add_action("wp_ajax_save_classm8_game_description", function(){

    $user = wp_get_current_user();
    if(!in_array($user -> roles[0] , array( 'administrator', 'classm8_admin'))){
        echo "No authentication".$user -> roles[0];
        die;
    }

    $server = get_option('classm8_server');

    if(!$server){
	echo "Add server options!";
	die;
    }


    $post_content = $_POST['description'];
    $game_id =  (is_numeric($_POST['game_id']) ? (int)$_POST['game_id'] : 0);

    if(!is_int($game_id)){
	echo "game id error";
	die;
    }
    
    $post_title = 'cl_game_desc_'.md5($server).'_'.$game_id;

    $post = get_page_by_title($post_title, OBJECT, 'classm8_g_desc');


    if($post){
	$id = $post -> ID; 
    }
    else {
	$id = null;
    }

    $post_id = wp_insert_post(array(
		    'ID' => $id,
		    'post_title'=>$post_title, 
		    'post_type'=>'classm8_g_desc', 
		    'post_content'=> $post_content
		), true);

    echo $_POST['description'];
    //echo "success";
    die;

});
add_action("wp_ajax_nopriv_save_classm8_game_description", function(){echo 'No access'; die;} );


?>